@@ -15,9 +15,11 @@
 #' to other databases hosted by the European Bioinformatics Institute (EBI).
 #'
 #' For more information about Europe PMC, see their current paper:
-#' Levchenko, M., Gou, Y., Graef, F., Hamelers, A., Huang, Z., Ide-Smith, M.,
-#'  … McEntyre, J. (2017). Europe PMC in 2017. Nucleic Acids Research, 46(D1),
-#'  D1254–D1260. \doi{10.1093/nar/gkx1005}.
+#' Ferguson, C., Araújo, D., Faulk, L., Gou, Y., Hamelers, A., Huang, Z., 
+#' Ide-Smith, M., Levchenko, M., Marinos, N., Nambiar, R., Nassar, M., Parkin, M.,
+#' Pi, X., Rahman, F., Rogers, F., Roochun, Y., Saha, S., Selim, M., Shafique, Z.,
+#' … McEntyre, J. (2020). Europe PMC in 2020. Nucleic Acids Research, 49(D1), 
+#' D1507–D1514. \doi{10.1093/nar/gkaa994}.
 
 #'
 #' @name europepmc
@@ -38,4 +40,4 @@
 #' @importFrom tibble as_tibble tibble
 #' @importFrom tidyr unnest
 #' @importFrom rlang .data
-NULL
+"_PACKAGE"
